==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_6_1/jsd_cad522e57a7b96b7238935689ed.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center UpdatePortAssignmentsV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCad522E57A7B96B7238935689Ed(object):
    """UpdatePortAssignmentsV1 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorCad522E57A7B96B7238935689Ed, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "authenticateTemplateName": {
                "enum": [
                "No Authentication",
                "Open Authentication",
                "Closed Authentication",
                "Low Impact"
                ],
                "type": "string"
                },
                "connectedDeviceType": {
                "enum": [
                "USER_DEVICE",
                "ACCESS_POINT",
                "TRUNKING_DEVICE",
                "AUTHENTICATOR_SWITCH",
                "SUPPLICANT_BASED_EXTENDED_NODE"
                ],
                "type": "string"
                },
                "dataVlanName": {
                "type": "string"
                },
                "fabricId": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "interfaceDescription": {
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "networkDeviceId": {
                "type": "string"
                },
                "scalableGroupName": {
                "type": "string"
                },
                "voiceVlanName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_9/jsd_cad522e57a7b96b7238935689ed.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center UpdatePortAssignmentsV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorCad522E57A7B96B7238935689Ed(object):
    """UpdatePortAssignmentsV1 request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorCad522E57A7B96B7238935689Ed, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "authenticateTemplateName": {
                "enum": [
                "No Authentication",
                "Open Authentication",
                "Closed Authentication",
                "Low Impact"
                ],
                "type": "string"
                },
                "connectedDeviceType": {
                "enum": [
                "USER_DEVICE",
                "ACCESS_POINT",
                "TRUNKING_DEVICE",
                "AUTHENTICATOR_SWITCH",
                "SUPPLICANT_BASED_EXTENDED_NODE"
                ],
                "type": "string"
                },
                "dataVlanName": {
                "type": "string"
                },
                "fabricId": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "interfaceDescription": {
                "type": "string"
                },
                "interfaceName": {
                "type": "string"
                },
                "networkDeviceId": {
                "type": "string"
                },
                "scalableGroupName": {
                "type": "string"
                },
                "voiceVlanName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
